@@ -1,7 +1,7 @@
 """Top-level package for tgsender."""
-from .tgsender import main, get_data_upload_plan
 from . import api
+from .tgsender import get_data_upload_plan, main
 
 __author__ = """apenasrr"""
 __email__ = "apenasrr@gmail.com"
-__version__ = "0.1.0"
+__version__ = "0.1.1"
